==> types_boto3_full-1.35.90.tar.gz: types_boto3_full-1.35.90/types_boto3_marketplacecommerceanalytics/type_defs.py <==
"""
Type annotations for marketplacecommerceanalytics service type definitions.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_marketplacecommerceanalytics/type_defs/)

Usage::

    ```python
    from types_boto3_marketplacecommerceanalytics.type_defs import TimestampTypeDef

    data: TimestampTypeDef = ...
    ```

Copyright 2024 Vlad Emelianov
"""

from __future__ import annotations

import sys
from datetime import datetime
from typing import Mapping, Union

from .literals import DataSetTypeType, SupportDataSetTypeType

if sys.version_info >= (3, 12):
    from typing import NotRequired, TypedDict
else:
    from typing_extensions import NotRequired, TypedDict


__all__ = (
    "GenerateDataSetRequestRequestTypeDef",
    "GenerateDataSetResultTypeDef",
    "ResponseMetadataTypeDef",
    "StartSupportDataExportRequestRequestTypeDef",
    "StartSupportDataExportResultTypeDef",
    "TimestampTypeDef",
)

TimestampTypeDef = Union[datetime, str]


class ResponseMetadataTypeDef(TypedDict):
    RequestId: str
    HTTPStatusCode: int
    HTTPHeaders: dict[str, str]
    RetryAttempts: int
    HostId: NotRequired[str]


class GenerateDataSetRequestRequestTypeDef(TypedDict):
    dataSetType: DataSetTypeType
    dataSetPublicationDate: TimestampTypeDef
    roleNameArn: str
    destinationS3BucketName: str
    snsTopicArn: str
    destinationS3Prefix: NotRequired[str]
    customerDefinedValues: NotRequired[Mapping[str, str]]


class StartSupportDataExportRequestRequestTypeDef(TypedDict):
    dataSetType: SupportDataSetTypeType
    fromDate: TimestampTypeDef
    roleNameArn: str
    destinationS3BucketName: str
    snsTopicArn: str
    destinationS3Prefix: NotRequired[str]
    customerDefinedValues: NotRequired[Mapping[str, str]]


class GenerateDataSetResultTypeDef(TypedDict):
    dataSetRequestId: str
    ResponseMetadata: ResponseMetadataTypeDef


class StartSupportDataExportResultTypeDef(TypedDict):
    dataSetRequestId: str
    ResponseMetadata: ResponseMetadataTypeDef

==> types_boto3_full-1.36.26.tar.gz: types_boto3_full-1.36.26/types_boto3_marketplacecommerceanalytics/type_defs.py <==
"""
Type annotations for marketplacecommerceanalytics service type definitions.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_marketplacecommerceanalytics/type_defs/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from types_boto3_marketplacecommerceanalytics.type_defs import TimestampTypeDef

    data: TimestampTypeDef = ...
    ```
"""

from __future__ import annotations

import sys
from datetime import datetime
from typing import Union

from .literals import DataSetTypeType, SupportDataSetTypeType

if sys.version_info >= (3, 9):
    from builtins import dict as Dict
    from collections.abc import Mapping
else:
    from typing import Dict, Mapping
if sys.version_info >= (3, 12):
    from typing import NotRequired, TypedDict
else:
    from typing_extensions import NotRequired, TypedDict


__all__ = (
    "GenerateDataSetRequestTypeDef",
    "GenerateDataSetResultTypeDef",
    "ResponseMetadataTypeDef",
    "StartSupportDataExportRequestTypeDef",
    "StartSupportDataExportResultTypeDef",
    "TimestampTypeDef",
)

TimestampTypeDef = Union[datetime, str]


class ResponseMetadataTypeDef(TypedDict):
    RequestId: str
    HTTPStatusCode: int
    HTTPHeaders: Dict[str, str]
    RetryAttempts: int
    HostId: NotRequired[str]


class GenerateDataSetRequestTypeDef(TypedDict):
    dataSetType: DataSetTypeType
    dataSetPublicationDate: TimestampTypeDef
    roleNameArn: str
    destinationS3BucketName: str
    snsTopicArn: str
    destinationS3Prefix: NotRequired[str]
    customerDefinedValues: NotRequired[Mapping[str, str]]


class StartSupportDataExportRequestTypeDef(TypedDict):
    dataSetType: SupportDataSetTypeType
    fromDate: TimestampTypeDef
    roleNameArn: str
    destinationS3BucketName: str
    snsTopicArn: str
    destinationS3Prefix: NotRequired[str]
    customerDefinedValues: NotRequired[Mapping[str, str]]


class GenerateDataSetResultTypeDef(TypedDict):
    dataSetRequestId: str
    ResponseMetadata: ResponseMetadataTypeDef


class StartSupportDataExportResultTypeDef(TypedDict):
    dataSetRequestId: str
    ResponseMetadata: ResponseMetadataTypeDef
